@@ -151,7 +151,7 @@ c        check job
       call cwhatJob
 c          this is moved here; before v6.10 it was before cwhatJob
       call ciniTracking0  !  init for  tracking for all events
-c           init for knockon process; Knockon is not used now.
+c           init for knockon process; Knockon below is not used now.
       if(KnockOnRatio .lt. 1.d0) then
 c              ********* Knockon is not used now ******
          if(Job .eq. 'newskel') then
@@ -167,6 +167,11 @@ c           flesh time
             call cerrorMsg('KnockOnRatio<1 and others mismatch', 0)
          endif
       else
+!!!         call cdedxEleci(RecoilKineMinE, Knockon)  replaced by next few lines
+!!             v7.643
+         if( knockOnRatio == 1.0d0 .or. RecoilKineMinE == 0.) then
+            RecoilKineMinE= KEminObs(1)
+         endif
          call cdedxEleci(RecoilKineMinE, Knockon)
       endif
 c         user hook
