@@ -30,7 +30,33 @@ c
          q.fm.p(3) = p1.fm.p(3) + p2.fm.p(3)
          q.fm.p(4) = p1.fm.p(4) + p2.fm.p(4)
         end         
+      subroutine cgeqm2(p1, p2, q, icon)
+      !   if p1/p2 is  nucleus, /n energy is used
+      !   to get q
+#include  "Zptcl.h"
+#include  "Zcode.h"
+         record /ptcl/ p1, p2
+         record /ptcl/ q
+         integer icon
+
+         record /ptcl/ pp1, pp2
+         if( p1.code == kgnuc ) then
+            call cmkptc(6, -1, 1, pp1)
+            pp1.fm.p(1:4) = p1.fm.p(1:4)/p1.subcode
+         else
+            pp1 = p1
+         endif
 
 
+         if( p2.code == kgnuc ) then
+            call cmkptc(6,-1,1, pp2)
+            pp2.fm.p(1:4) = p2.fm.p(1:4)/p2.subcode
+         else
+            pp2 = p2
+         endif
 
+         call cgeqm(pp1, pp2, q, icon)
+         end
+
+      
 
