@@ -75,9 +75,6 @@ c          inicident.where can be fixed here. not  in cmkIncidnt
          incident.where = NoOfSites + 1
          IncidentCopy.where = incident.where
  222     continue
-c///////////
-         write(0,*) ' incident.where=',incident.where
-c///////////
       elseif(ObsPlane .eq.  notUsed ) then
 c           Nothing to do. observation is at height =
 c           BorderHeighL. (for neutrino)
