@@ -2,6 +2,7 @@
 c            treat interaction of MovedTrack
 c
       subroutine cinteraction
+      use modXsecMedia
       implicit none
 
 #include  "Zcode.h"
@@ -27,6 +28,11 @@ c
       integer stackpos
       save never
       integer icon
+      integer,parameter::loopmax=100
+      integer:: loopc
+
+
+
 cc      record /ptcl/ fragA(maxHeavyMassN),  nonIntNucA(maxHeavyMassN)
 cc      integer noOfFrag, noOfNonIntN
 c
@@ -34,9 +40,22 @@ c      record /track/aTrack
 c
 c   **  ptcl stacking is done in each subroutine; should be changed
 c           (except for hadronic interactions)
+c       logic of employing events satisfying some conditions only 
+c
+c        generate 1 event ; data is in PWork(:)
+c        call chookNEPInt(neverNEP)  ! the user may give 5 to neverNEP
+c                                  ! to discard the current event
+c        never = neverNEP
+c        
+c           
+c
 
-      Nproduced = 0
-
+      loopc = 0
+      do while (loopc < loopmax )
+!          try until desired event is generated
+!          (mainly for multiple production)
+         loopc = loopc + 1
+         Nproduced = 0
 
 c
 cc    assume MovedTrack is not changed in interaction routine
@@ -44,34 +63,36 @@ c     but may be added asflag by chookEing if it is elec.
 c      (in the case of Job ='newskel' )
 c     
 c
-      if(MovedTrack.p.code .eq. kelec) then
-         call cinteElec
-      elseif(MovedTrack.p.code .eq. kphoton) then
-         call cintePhoton
-      else
-         call cinteNEP
-         if(IntInfArray(ProcessNo).process .eq. 'coll') then
-            MovedTrack.pos.colheight = MovedTrack.pos.height
+         if(MovedTrack.p.code .eq. kelec) then
+            call cinteElec
+         elseif(MovedTrack.p.code .eq. kphoton) then
+            call cintePhoton
+         else
+            call cinteNEP
+            if(IntInfArray(ProcessNo).process .eq. 'coll') then
+               MovedTrack.pos.colheight = MovedTrack.pos.height
+            endif
          endif
-      endif
 
-      if(MovedTrack.p.code .eq. kelec) then
-         if(neverE .ne. 1) then
-            call chookEInt(neverE)
-            never = neverE
+         if(MovedTrack.p.code .eq. kelec) then
+            if(neverE .ne. 1) then
+               call chookEInt(neverE)
+               never = neverE
+            endif
+         elseif(MovedTrack.p.code .eq. kphoton) then
+            if(neverG  .ne. 1)  then
+               call chookGInt(neverG)
+               never = neverG
+            endif
+         else
+            if(neverNEP .ne. 1) then
+               call chookNEPInt(neverNEP)
+               never = neverNEP
+            endif
          endif
-      elseif(MovedTrack.p.code .eq. kphoton) then
-          if(neverG  .ne. 1)  then
-             call chookGInt(neverG)
-             never = neverG
-          endif
-      else
-         if(neverNEP .ne. 1) then
-            call chookNEPInt(neverNEP)
-            never = neverNEP
-         endif
-      endif
-
+         if( never /= 5) exit
+         never = 0
+      enddo   ! end of while;   
       if(btest(Eabsorb(1), BitEconsv-1) ) then
          if(IntInfArray(ProcessNo).process .eq. 'coll' .or.
      *        IntInfArray(ProcessNo).process .eq. 'photop' .or.
@@ -79,6 +100,8 @@ c
 
 c                                    last one not used yet
             call chookEabsorbC( MovedTrack, Nproduced,  Pwork, 0)
+c               what is being done below is almost the same as
+c               done above call.
             Ein1 = MovedTrack.p.fm.p(4)  
      *           + masn*(TargetNucleonNo-TargetProtonNo) +
      *           masp*TargetProtonNo
@@ -165,6 +188,8 @@ c                 stack the leading ptcl  first (to save stack area)
          MovedTrack.vec = IncidentCopy.vec
          call cmovePtcl1(MovedTrack, Pwork, Nproduced, Nstacked)
       endif
+
+
       if(never .eq. 0 .or. never .eq. 1 ) then
 c          user may set never=3 
       elseif(never .eq. 3) then
@@ -173,13 +198,15 @@ c          don't follow this and  child; reset stackpos
          stackpos=stackpos-Nstacked
          call cresetStackpos(stackpos)
       elseif(never .eq. 4) then
-c             discard this event
+c             discard this event generated by the current primary
 c             clear stack
          call cinitStack
       else
-         call cerrorMsg('return value from chookE,G,NEPInt wrong', 0)
+         call cerrorMsg('return value from chookE,G,NEPInt wrong', 1)
          write(0,*)  ' never=', never
+         stop
       endif
+
       end
 c          following is remnant of never=2 and ad-hoc model
 c          when chookNEPInt is called before push is called.
