@@ -1,5 +1,6 @@
-c        csampGIntL:  sample phtoto interaction length.
+c        csampGIntL:  sample photon interaction length.
        subroutine csampGIntL
+       use modXsecMedia
 c
 c        pair, compton, photo-electric eff. photo-hadron
 c
@@ -8,12 +9,13 @@ c
 #include  "Ztrack.h"
 #include  "Ztrackp.h"
 #include  "Ztrackv.h"
+#include  "Zevhnv.h"
 #include  "Zelemagp.h"
 
 c
 
        real*8  t, tkgpm2, cxai, den, cvh2den, eg
-       real*8  prob, u, cmPairMFP
+       real*8  prob, u, cmPairMFP, mfp, xs
        real*8  tcomp, tphot, tpair, tgp, tcoh
        real*8 xprob(5), txray(5)
             
@@ -61,7 +63,11 @@ c           use Xcom data
        endif
 c           photo hadron prod.
        if( eg .gt. MinPhotoProdE .and. HowPhotoP > 0 ) then
-          call cghPath(eg,    tkgpm2)
+          call cgetPhotoPxs(ActiveMdl2, TrackBefMove.p,
+     *       media(1), xs, mfp)    ! xs in mb. mfp in kg/m2
+          call rndc(u)
+          tkgpm2 = -mfp*log(u)
+!!!          call cghPath(eg,    tkgpm2)  ! old interface
           call csetIntInf(tkgpm2, .false., 'photop')
        endif
 
