@@ -17,7 +17,10 @@ c     **************************************************
 cc      real*8 u, iwgt	
       real*8 cosfromaxis
       external cblkTracking
-
+c//////
+      logical show
+      common /showshow/ show
+c////////////
 c
 c      ***  do until no more ptcl in stack
       do while (.true.)
@@ -26,13 +29,6 @@ c           get one particle from stack
          if(moreptcl .eq. 0) goto 100   !  exit
          call rndsw(jold, 1)            !  specify 1st generator.
          call cifDead(TrackBefMove, icon)  ! generator may be switched to 2
-c//////////
-c         if( icon /= 0 .and.  
-c     *      TrackBefMove.p.fm.p(4)-TrackBefMove.p.mass > 0.05 ) then
-c            write(0,*) ' H.E dead icon=',icon
-c            stop
-c         endif
-c//////////////
             
 c                     icon=0; alive, 1 E<Emin, 2 long flight 3 h>H 4 h<L
 c                             5 angle>limit
@@ -128,21 +124,8 @@ c           Truncate the path if it is too long. Note, the truncated
 c           path in the above process may be again truncated to
 c           a shorter one. This happens, for example, if ptcl energy
 c           is low.  Path inf is reset in IntInfArray.
-c///////////
-      if(show) then
-         write(0,*) ' bef truncpath'
-         write(0,*) ' MoveStat=',MoveStat
-      endif
-c//////////////
       call ctruncPath
 
-c///////////
-      if(show) then
-         write(0,*) ' bef truncpath'
-         write(0,*) ' MoveStat=',MoveStat
-      endif
-c//////////////
-
 #if DEBUG == 1
       call checkstat('after ctruncPath')
 #endif
@@ -151,12 +134,6 @@ c           compute path end inf. including scattering and
 c           mag. deflection.  Path end inf is set in MovedTrack
 
       call ccompPathEnd
-c///////////
-      if(show) then
-         write(0,*) ' afte ccompPathend'
-         write(0,*) ' MoveStat=',MoveStat
-      endif
-c//////////////
 
 #if DEBUG == 1
       call checkstat('after ccompPathEnd')
@@ -186,12 +163,6 @@ c               4th arg. not used now
 c            the user may kill the ptcl
       call cobservation(8)
 #endif
-c//////////
-      if(show) then
-         write(0,*) ' MoveStat=',MoveStat, Truncated
-         write(0,*) ' ToInteract', ToInteract
-      endif
-c/////////////////
 
 c     
       if(MoveStat .eq. Truncated) then
@@ -250,19 +221,7 @@ c               call cresetTimer(MovedTrack)
 #if DEBUG == 1
          call checkstat('before cinteraction')
 #endif
-c//////////////
-         if(show) then
-            write(0,*) 'e ntering interaction'
-         endif
-c/////////////////
          call cinteraction
-c////////
-         if(show) then
-            write(0,*) 'back from cinerac'
-         endif
-c//////////////
-
-
       elseif(MoveStat .eq. ToBeObserved ) then
          ptclidx = MovedTrack.p.code  ! make 4 byte integer
          ptclidx = min(ptclidx, 8)   ! this is only for using KEminObs
@@ -355,7 +314,7 @@ c         MovedTrack.t = 0.     ! bug bef uv6.09 ;;; but why commentout ???
       endif
       end
 C           if you activate the next routine, Epics will have link problem!!!
-#if DEBUG > 0
+cccc   #if DEBUG > 0
       subroutine checkstat(str)
       implicit none
 #include  "Ztrack.h"
@@ -396,7 +355,7 @@ c      if( deb) then
 c         endif
 c         endif
       end
-#endif
+ccccc  #endif
 c-------------------------------------------------------
       subroutine cfixMag
       implicit none
@@ -495,18 +454,6 @@ c
             call csampNEPIntL   ! non Electron Photon  Interaction.
          endif
          call cfixProc
-c///////////////
-         if( TrackBefMove.p.code == 6 .and.
-     *       TrackBefMove.p.charge == -1 .and.
-     *     (  TrackBefMove.p.fm.p(4)-TrackBefMove.p.mass < 
-     *         0.1 ) ) then
-            show = .true.
-            write(0,*) ' fix proc =',
-     *        IntInfArray(ProcessNo).process
-         else
-            show = .false.
-         endif
-c//////////////////
          if( IntInfArray(ProcessNo).process == 'coll' ) then
 !               some of the code can not deal with coll.of sigma 
 !               etc.
@@ -516,11 +463,6 @@ c//////////////////
                call cresetIntInf
             else
                call cfixTarget( media(1) )
-c///////////////
-               if(show) then
-                  write(0,*)' TargetNucleonNo=',TargetNucleonNo
-               endif
-c///////////////////
             endif
          elseif( IntInfArray(ProcessNo).process == 'photop') then
             call  cfixTarget( media(1) )
@@ -552,11 +494,6 @@ c
        minlen = Infty + Infty
 c              get vertical height
        h = TrackBefMove.pos.height
-c/////////
-c       write(0,*) 'NumberOf Inte=', NumberOfInte,
-c     * ' height=',h
-c////////
-
        do i = 1, NumberOfInte
          if(.not. IntInfArray(i).decay) then
 c              convert kg/m2 into length
@@ -594,11 +531,6 @@ c                  some work around for insufficient accuracy
             minlen = leng
          endif
       enddo
-c//////////////////
-c      write(0,*) ' pcor=',ProcessNo, ' leng=',minlen, ' Moves',
-c     *   MoveStat
-c/////////////
-
 c      if(leng .ge. minlen) then  !   bug in 6.00
 c      if(leng .ge. Infty) then  
 c         ProcessNo = 1
@@ -631,45 +563,43 @@ c        given in InfIntArray is too long, or the path traverses
 c        an observation depth.
       subroutine ctruncPath
       implicit none
-
+#include  "Zcode.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
 
       real*8 leng, thick
+      real(8),parameter::veryshort=0.1 ! 10cm
+      real(8),parameter::verylow=2d-3 !  2MeV
 c
 c//////////////////
       logical show
       common /showshow/ show
 c////////////
       call cmaxMovLen(leng, thick)
-c//////////
-      if(show) then
-       write(0,*) ' after maxMovLen, leng=',leng, ' thick=',thick
-       write(0,*) '  IntInfArray.length=',IntInfArray(ProcessNo).length
-       write(0,*) ' procno=', ProcessNo, ' process=', 
-     *   IntInfArray(ProcessNo).process
-      endif
-cc//////////
-
       if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
          IntInfArray(ProcessNo).thickness  = thick
-c//////////
-c      else
-c         if(TrackBefMove.pos.height .eq. 100.d3 .and.
-c     *     IntInfArray(ProcessNo).thickness .lt. 10.0d0) then
-c            write(*,*) 100.d3- IntInfArray(ProcessNo).length, 
-c     *      IntInfArray(ProcessNo).thickness
-c         endif
-c         write(*,*) 'thru: maxlen=',leng, ' thick=',thick,
-c     *  ' proce no=',ProcessNo, ' proc=',
-c     *    IntInfArray(ProcessNo).process,
-c     *    ' Bef H=',TrackBefMove.pos.height,
-c     *    ' Bef D=',TrackBefMove.pos.depth,
-c     * ' int leng=',  IntInfArray(ProcessNo).length, 
-c    * ' int thick=',  IntInfArray(ProcessNo).thickness
-c////////////
+         if(leng < veryshort ) then
+!            some very unhappy case, B and dE/dx forces
+!             muon (typically) path very short and the
+!             muon cannot decay, while E loss is very small
+!             and muon KE is still > 0 after the path.
+!             This is repeated and KE becomes smaller and
+!             smaller (say, until 10^-13 GeV); it may need
+!             huge steps for traveling only a few cm and   
+!             cpu time more than 5 sec.  This is avoided
+!             by next 
+            if( MovedTrack.p.code == kmuon .or.
+     *          MovedTrack.p.code == kpion .or.
+     *          MovedTrack.p.code == kkaon ) then
+               if( MovedTrack.p.fm.p(4)- MovedTrack.p.mass 
+     *            < verylow ) then
+!                  force to decay; 
+                  MoveStat = ToInteract
+               endif
+            endif
+         endif
       endif
       end
 c      *************** for same model, we must use simple super position for heavy
