@@ -1,16 +1,19 @@
 #ifndef Zcondc_
 #define  Zcondc_
-!  define EFIELD  0 if Electric field is to be supplied 
+!  define MYEFIELD  if Electric field is to be supplied 
 !  by the user using cmyEfield.f of which template is
 !  in UserHook/.  The user may copy it to the users
-!  application area, modify it and may add #include cmyEfiled.f in
-!  the chook.f. Also the user must give a value of
-!  >1 to the 'HowEfield' parameter  in the namelist.
+!  application area, modify it and may add  cmyEfield.o in
+!  the chook.mk like:
+!      objs =  chook.o cmyEfield.o
+!  Also the user must give a value of
+!  >1 to the 'HowEfield' parameter  in the namelist ($HPARAM).
 !  Note simple Electric field can be specified
 !  without using this but by giving HowEfield=1 in the
-!  namelist parameter (HPARM). Then simple electric
+!  namelist parameter.  Then simple electric
 !  field can be specified (together with other parameters)
-#undef EFIELD 
+#undef MYEFIELD 
+!!! define MYEFIELD
 !   dpmjet cannot be used on NEXTSTEP, so
 !   you have to make the next 0. 
 #ifdef NEXT486
@@ -37,7 +40,7 @@
 !           or  new with linear interp.
 !               new atmosphere --> 2 (default)
 !           or  NRL atmosphere --> 3
-#define  ATMOSPHERE  2
+#define ATMOSPHERE 2
 
 !     if you want to put a lable on each particle to identify that
 !     the one and the same particle crosses a given observation
